@@ -188,10 +188,9 @@ class WebhookRequestHandler(web.View):
 
             if fut.done():
                 return fut.result()
-            else:
-                # context.set_value(WEBHOOK_CONNECTION, False)
-                fut.remove_done_callback(cb)
-                fut.add_done_callback(self.respond_via_request)
+            # context.set_value(WEBHOOK_CONNECTION, False)
+            fut.remove_done_callback(cb)
+            fut.add_done_callback(self.respond_via_request)
         finally:
             timeout_handle.cancel()
 
@@ -242,6 +241,8 @@ class WebhookRequestHandler(web.View):
         # For reverse proxy (nginx)
         forwarded_for = self.request.headers.get('X-Forwarded-For', None)
         if forwarded_for:
+            # get the left-most ip when there is multiple ips (request got through multiple proxy/load balancers)
+            forwarded_for = forwarded_for.split(",")[0]
             return forwarded_for, _check_ip(forwarded_for)
 
         # For default method
