@@ -67,7 +67,7 @@ class ReplyKeyboardMarkup(base.TelegramObject):
             if index % self.row_width == 0:
                 self.keyboard.append(row)
                 row = []
-        if len(row) > 0:
+        if row:
             self.keyboard.append(row)
         return self
 
@@ -79,9 +79,7 @@ class ReplyKeyboardMarkup(base.TelegramObject):
         :return: self
         :rtype: :obj:`types.ReplyKeyboardMarkup`
         """
-        btn_array = []
-        for button in args:
-            btn_array.append(button)
+        btn_array = [button for button in args]
         self.keyboard.append(btn_array)
         return self
 
@@ -131,7 +129,9 @@ class KeyboardButton(base.TelegramObject):
 
 class ReplyKeyboardRemove(base.TelegramObject):
     """
-    Upon receiving a message with this object, Telegram clients will remove the current custom keyboard and display the default letter-keyboard. By default, custom keyboards are displayed until a new keyboard is sent by a bot. An exception is made for one-time keyboards that are hidden immediately after the user presses a button (see ReplyKeyboardMarkup).
+    Upon receiving a message with this object, Telegram clients will remove the current custom keyboard
+    and display the default letter-keyboard. By default, custom keyboards are displayed until a new keyboard is sent by a bot.
+    An exception is made for one-time keyboards that are hidden immediately after the user presses a button (see ReplyKeyboardMarkup).
 
     https://core.telegram.org/bots/api#replykeyboardremove
     """
